==> jc-1.4.0.tar.gz: gnu/xml/transform/FormatNumberFunction.h <==
// final class gnu.xml.transform.FormatNumberFunction

// class file dependencies
// @dep_class 7aad82e7da0f04b4 gnu_xml_transform_FormatNumberFunction
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_transform_FormatNumberFunction_H_
#define _JC_gnu_xml_transform_FormatNumberFunction_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_FormatNumberFunction$sub_refs	_jc_gnu_xml_transform_FormatNumberFunction$sub_refs;
typedef struct _jc_gnu_xml_transform_FormatNumberFunction$sub_nonrefs	_jc_gnu_xml_transform_FormatNumberFunction$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_FormatNumberFunction$refs	_jc_gnu_xml_transform_FormatNumberFunction$refs;
typedef struct _jc_gnu_xml_transform_FormatNumberFunction$nonrefs	_jc_gnu_xml_transform_FormatNumberFunction$nonrefs;
typedef struct _jc_gnu_xml_transform_FormatNumberFunction$object	_jc_gnu_xml_transform_FormatNumberFunction$object;

typedef const struct _jc_gnu_xml_transform_FormatNumberFunction$vmethods	_jc_gnu_xml_transform_FormatNumberFunction$vmethods;
typedef const struct _jc_gnu_xml_transform_FormatNumberFunction$vtable	_jc_gnu_xml_transform_FormatNumberFunction$vtable;
typedef const struct _jc_gnu_xml_transform_FormatNumberFunction$vtype	_jc_gnu_xml_transform_FormatNumberFunction$vtype;

// Constructors
extern void _jc_gnu_xml_transform_FormatNumberFunction$method$_init$12c4ddb4b942002a(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_transform_FormatNumberFunction$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_FormatNumberFunction$method$evaluate$f399496e60bca5df(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_FormatNumberFunction$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_object *, jint, jint);
extern void _jc_gnu_xml_transform_FormatNumberFunction$method$setArguments$09123773dfa6e512(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_FormatNumberFunction$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_transform_FormatNumberFunction$method_info$evaluate$f399496e60bca5df;
extern _jc_method _jc_gnu_xml_transform_FormatNumberFunction$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_transform_FormatNumberFunction$method_info$setArguments$09123773dfa6e512;

// Virtual methods structure
struct _jc_gnu_xml_transform_FormatNumberFunction$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*evaluate$f399496e60bca5df)(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_object *, jint, jint);
	void	(*setArguments$09123773dfa6e512)(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_xml_transform_FormatNumberFunction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_transform_FormatNumberFunction$vmethods	gnu_xml_transform_FormatNumberFunction;
};

// Vtype
struct _jc_gnu_xml_transform_FormatNumberFunction$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_FormatNumberFunction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_FormatNumberFunction$sub_refs {
	struct _jc_gnu_xml_transform_Stylesheet$object	*stylesheet;
	struct _jc_object	*args;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_FormatNumberFunction$refs {
    _jc_gnu_xml_transform_FormatNumberFunction$sub_refs	gnu_xml_transform_FormatNumberFunction;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_FormatNumberFunction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_FormatNumberFunction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_transform_FormatNumberFunction$sub_nonrefs	gnu_xml_transform_FormatNumberFunction;
};

// Object instance structure
struct _jc_gnu_xml_transform_FormatNumberFunction$object {
	_jc_gnu_xml_transform_FormatNumberFunction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_FormatNumberFunction$vtype	*vtype;
	_jc_gnu_xml_transform_FormatNumberFunction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_FormatNumberFunction$vtype _jc_gnu_xml_transform_FormatNumberFunction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_FormatNumberFunction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_FormatNumberFunction$class_object;

#endif	/* _JC_gnu_xml_transform_FormatNumberFunction_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/transform/FormatNumberFunction.h <==
// final class gnu.xml.transform.FormatNumberFunction

// class file dependencies
// @dep_class 7aad82e7da0f04b4 gnu_xml_transform_FormatNumberFunction
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_transform_FormatNumberFunction_H_
#define _JC_gnu_xml_transform_FormatNumberFunction_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_FormatNumberFunction$sub_refs	_jc_gnu_xml_transform_FormatNumberFunction$sub_refs;
typedef struct _jc_gnu_xml_transform_FormatNumberFunction$sub_nonrefs	_jc_gnu_xml_transform_FormatNumberFunction$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_FormatNumberFunction$refs	_jc_gnu_xml_transform_FormatNumberFunction$refs;
typedef struct _jc_gnu_xml_transform_FormatNumberFunction$nonrefs	_jc_gnu_xml_transform_FormatNumberFunction$nonrefs;
typedef struct _jc_gnu_xml_transform_FormatNumberFunction$object	_jc_gnu_xml_transform_FormatNumberFunction$object;

typedef const struct _jc_gnu_xml_transform_FormatNumberFunction$vmethods	_jc_gnu_xml_transform_FormatNumberFunction$vmethods;
typedef const struct _jc_gnu_xml_transform_FormatNumberFunction$vtable	_jc_gnu_xml_transform_FormatNumberFunction$vtable;
typedef const struct _jc_gnu_xml_transform_FormatNumberFunction$vtype	_jc_gnu_xml_transform_FormatNumberFunction$vtype;

// Constructors
extern void _jc_gnu_xml_transform_FormatNumberFunction$method$_init$12c4ddb4b942002a(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_transform_FormatNumberFunction$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_FormatNumberFunction$method$evaluate$f399496e60bca5df(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_FormatNumberFunction$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_transform_FormatNumberFunction$method$setArguments$09123773dfa6e512(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_FormatNumberFunction$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_transform_FormatNumberFunction$method_info$evaluate$f399496e60bca5df;
extern _jc_method _jc_gnu_xml_transform_FormatNumberFunction$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_transform_FormatNumberFunction$method_info$setArguments$09123773dfa6e512;

// Virtual methods structure
struct _jc_gnu_xml_transform_FormatNumberFunction$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*evaluate$f399496e60bca5df)(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
	void	(*setArguments$09123773dfa6e512)(_jc_env *, struct _jc_gnu_xml_transform_FormatNumberFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_FormatNumberFunction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_transform_FormatNumberFunction$vmethods	gnu_xml_transform_FormatNumberFunction;
};

// Vtype
struct _jc_gnu_xml_transform_FormatNumberFunction$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_FormatNumberFunction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_FormatNumberFunction$sub_refs {
	struct _jc_gnu_xml_transform_Stylesheet$object	*stylesheet;
	struct _jc_object	*args;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_FormatNumberFunction$refs {
    _jc_gnu_xml_transform_FormatNumberFunction$sub_refs	gnu_xml_transform_FormatNumberFunction;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_FormatNumberFunction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_FormatNumberFunction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_transform_FormatNumberFunction$sub_nonrefs	gnu_xml_transform_FormatNumberFunction;
};

// Object instance structure
struct _jc_gnu_xml_transform_FormatNumberFunction$object {
	_jc_gnu_xml_transform_FormatNumberFunction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_FormatNumberFunction$vtype	*vtype;
	_jc_gnu_xml_transform_FormatNumberFunction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_FormatNumberFunction$vtype _jc_gnu_xml_transform_FormatNumberFunction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_FormatNumberFunction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_FormatNumberFunction$class_object;

#endif	/* _JC_gnu_xml_transform_FormatNumberFunction_H_ */
